@@ -59,7 +59,9 @@ class TestMultitenantAdminMixin(object):
         operator = User.objects.create_user(**opts)
         operator.user_permissions.add(*self.get_operator_permissions())
         for organization in organizations:
-            OrganizationUser.objects.create(user=operator, organization=organization)
+            OrganizationUser.objects.create(
+                user=operator, organization=organization, is_admin=True
+            )
         operator.organizations_dict  # force caching
         return operator
 
@@ -82,14 +84,18 @@ class TestMultitenantAdminMixin(object):
 
         # ensure elements in visible list are visible to operator
         for el in visible:
-            self.assertContains(
-                response, _f(el, select_widget), msg_prefix='[operator contains]'
-            )
+            with self.subTest(el):
+                self.assertContains(
+                    response, _f(el, select_widget), msg_prefix='[operator contains]'
+                )
         # ensure elements in hidden list are not visible to operator
         for el in hidden:
-            self.assertNotContains(
-                response, _f(el, select_widget), msg_prefix='[operator not-contains]'
-            )
+            with self.subTest(el):
+                self.assertNotContains(
+                    response,
+                    _f(el, select_widget),
+                    msg_prefix='[operator not-contains]',
+                )
 
         # now become superuser
         self._logout()
